#

##

##

###

###

##

##

###

###

##

###

###

###

###

##

##

##

    	goodest

    	objectives
    		https://hub.docker.com/r/eniocarboni/docker-ubuntu-systemd

    	on
    		1st session
    			#
    			#	if there's a docker conflict
    			#
    			#
    			docker rm $(docker ps -a -q)

    			#
    			#	on
    			#
    			docker compose up -d; docker exec -it goodest.1 bash

    			#
    			#	need to wait for this install to finish
    			#	before running source_2
    			#
    			. /habitat/_controls/build_1.sh

    			#
    			#	optional: HAProxy certs
    			#
    			#
    			goodest_1 adventures demux_hap build_unverified_certificates

    			goodest_1 ventures on
    			(cd /habitat/venues/stages/goodest/adventures/vv_turbo/ && bun run dev)
    			localStorage.setItem ("node address", "https://192.168.0.100/")

    			#
    			#	optional: if need to import the database
    			#
    			goodest_1 adventures monetary saves import --version 4 --drop

    		2nd+ session
    			docker exec -it goodest.1 bash -c "source /habitat/_controls/build_2.sh && bash"

    			#
    			#
    			#	build the front
    			#
    			(cd /habitat/venues/stages/goodest/adventures/vv_turbo/apps/web && the_version=1.8.0 bun run build --sourcemap inline)

    	off
    		docker container stop goodest.1; docker container rm goodest.1;

    	garages (harbors)
    		sanic
    			http://192.168.0.100/docs/swagger#/

    		sanic inspector
    			http://192.168.0.100:7457

    	publishing
    		linting
    			(cd /goodest/venues/stages/goodest && pycycle --here)

    		status
    			cd /goodest/venues/stages/goodest/__status/main

    			#
    			#	change the "essence" "mode" to "business"
    			#
    			#

    			#
    			#	monetary export
    			#
    			#

    			#
    			#	internal status
    			#
    			#
    			python3 /habitat/venues/stages/goodest/__status/main/status.proc.py

    			#
    			#	external API checks (NIH and USDA)
    			#
    			python3 /habitat/venues/stages/goodest/__status/API/status.proc.py

    			python3 /habitat/venues/stages/goodest/__status/monetary_export_3/status.proc.py

    			#
    			# 	vite status
    			#
    			#
    			(cd /habitat/venues/stages/goodest/adventures/vv_turbo/apps/web && bun run status)

    			#
    			#	selenium status (this is probably broken)
    			#
    			#
    			python3 /habitat/venues/stages/goodest/__status/browser/status.proc.py
    			python3 venues/stages/goodest/__status/browser/status.proc.py

    		publish
    			#
    			#	[ ] poetry auth
    			#
    			#	# For building sdist and maybe wheel
    			#		poetry build --verbos
    			#

    			git tag 1.11.0

    			(pip install poetry && cd /habitat && rm -rf dist && poetry build --format sdist --verbose && chmod -R 777 /habitat && poetry publish --verbose;)

    			#
    			#	statistics
    			#
    			find . -type d -exec du -sh {} \;
    			du -h --max-depth=1 .

    		notes
    			[tool.poetry.source]
    			include = [
    				"venues/stages/goodest/adventures/vv_turbo/apps/web/the_build/*"
    			]

    	important
    		poetry show --tree

    	docker
    		docker compose up -d
    		docker exec -it goodest bash
    		docker exec -it goodest bash -c "source /goodest/moves/source_2.sh && bash"

    	hatch
    		#
    		#	https://github.com/pypa/pipx
    		#
    		#
    		apt install pipx -y
    		pipx ensurepath
    		pipx install hatch